
local L = LibStub("AceLocale-3.0"):GetLocale("ZooKeeper", true)

local options

-- registration of options
function ZooKeeper:SetupOptions()
    self.options = self:GetOptions()
    self.config = LibStub("AceConfig-3.0")
    self.optionsDialog = LibStub("AceConfigDialog-3.0")
    self.config:RegisterOptionsTable("ZooKeeper", self.options, {"zookeeper", "zk"})
    self.optionsDialog:AddToBlizOptions("ZooKeeper", "ZooKeeper")
end

-- init of actual options table
function ZooKeeper:InitOptions()
    options = {
        type = 'group',
        args = {
            columns = {
                name = L['ParamColumnsName'],
                desc = L['ParamColumnsDesc'],
                type = 'range',
                min = 1,
                max = 20,
                step = 1,
                handler = self,
                set = 'SetColumns',
                get = 'GetColumns',
            },
            buttonPadding = {
                name = L['ParamButtonPaddingName'],
                desc = L['ParamButtonPaddingDesc'],
                type = 'range',
                min = 1,
                max = 20,
                step = 1,
                handler = self,
                set = 'SetButtonPadding',
                get = 'GetButtonPadding',
            },
            showWithPetPaperDoll = {
                name = L['ParamShowWithPetPaperDollName'],
                desc = L['ParamShowWithPetPaperDollDesc'],
                type = 'toggle',
                handler = self,
                set = 'SetShowWithPetPaperDoll',
                get = 'GetShowWithPetPaperDoll'
            },
            show = {
                name = L['ParamShowName'],
                desc = L['ParamShowDesc'],
                type = 'execute',
                guiHidden = true,
                handler = self,
                func = 'Show'
            },
            opacity = {
                name = L['ParamOpacityName'],
                desc = L['ParamOpacityDesc'],
                type = 'range',
                min = 0,
                max = 1,
                step = .05,
                handler = self,
                set = 'SetOpacity',
                get = 'GetOpacity'
            },
            scale = {
                name = L['ParamScaleName'],
                desc = L['ParamScaleDesc'],
                type = 'range',
                min = 0.3,
                max = 3.0,
                step = 0.1,
                handler = self,
                set = 'SetScale',
                get = 'GetScale'
            }
         }
    }

end

function ZooKeeper:GetOptions()
   if not options then
      self:InitOptions()
   end
   return options
end

function ZooKeeper:GetColumns()
   return self.db.columns
end

function ZooKeeper:SetColumns(info, value)
   self.db.columns = value
   self:Update()
end

function ZooKeeper:GetRows()
   return self.db.rows
end

function ZooKeeper:SetRows(info, value)
   self.db.rows = value
   self:Update()
end

function ZooKeeper:GetButtonPadding()
   return self.db.buttonPadding
end

function ZooKeeper:SetButtonPadding(info, value)
   self.db.buttonPadding = value
   self:Update()
end

function ZooKeeper:GetShowWithPetPaperDoll()
   return self.db.showWithPetPaperDoll
end

function ZooKeeper:SetShowWithPetPaperDoll(info, value)
   self.db.showWithPetPaperDoll = value
end

function ZooKeeper:GetOpacity()
   return self.db.opacity
end

function ZooKeeper:SetOpacity(info, value)
   self.db.opacity = value
   self.frame:UpdateBackdrop()
end

function ZooKeeper:GetScale()
   return self.db.scale
end

function ZooKeeper:SetScale(info, value)
   self.db.scale = value
   self.frame:SetScale(self.db.scale)
end
